@@ -11,12 +11,16 @@
 #include "command_p.h"
 
 #include <Libkleo/CryptoConfig>
-#include <Libkleo/Dn>
+#include <Libkleo/DnAttributes>
 #include <Libkleo/GnuPG>
 #include <Libkleo/KeyCache>
 
 #include "kleopatra_debug.h"
 #include <KLocalizedString>
+
+#include <QGpgME/DN>
+#include <qgpgme/qgpgme_version.h>
+
 #include <QSaveFile>
 
 #include <QByteArray>
@@ -33,6 +37,10 @@
 
 #include <algorithm>
 
+#if QGPGME_VERSION < QT_VERSION_CHECK(2, 0, 0)
+#include <Libkleo/Dn>
+#endif
+
 using namespace Kleo;
 using namespace Kleo::Commands;
 using namespace GpgME;
@@ -145,7 +153,7 @@ void ChangeRootTrustCommand::doCancel()
     d->canceled = true;
 }
 
-static QString change_trust_file(const QString &trustListFile, const QString &fingerprint, const DN &dn, Key::OwnerTrust trust);
+static QString change_trust_file(const QString &trustListFile, const QString &fingerprint, const QGpgME::DN &dn, Key::OwnerTrust trust);
 static QString run_gpgconf_reload_gpg_agent(const QString &gpgConfPath);
 
 void ChangeRootTrustCommand::Private::run()
@@ -154,7 +162,7 @@ void ChangeRootTrustCommand::Private::run()
 
     const auto key = keys().front();
     const QString fpr = QString::fromLatin1(key.primaryFingerprint());
-    const auto dn = DN(key.userID(0).id());
+    const auto dn = QGpgME::DN(key.userID(0).id());
     // Undefined means "fingerprint didn't match" -> do not trust this certificate
     const Key::OwnerTrust trust = this->trust == Key::Undefined ? Key::Never : this->trust;
     const QString trustListFile = this->trustListFile;
@@ -209,7 +217,16 @@ static KLocalizedString joinAsIndentedLines(const QStringList &strings)
 
 bool ChangeRootTrustCommand::Private::confirmOperation(const Key &key)
 {
+#if QGPGME_VERSION >= QT_VERSION_CHECK(2, 0, 0)
+    QGpgME::DN dn(key.userID(0).id());
+    dn.setAttributeOrder(DNAttributes::order());
+    const QStringList certificateAttributes = dn.prettyAttributes();
+#else
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_DEPRECATED
     const QStringList certificateAttributes = DN(key.userID(0).id()).prettyAttributes();
+    QT_WARNING_POP
+#endif
     const KLocalizedString certificateInfo = joinAsIndentedLines(certificateAttributes);
     {
         const QString question = (trust == GpgME::Key::Ultimate) //
@@ -268,7 +285,7 @@ public:
 }
 
 // static
-QString change_trust_file(const QString &trustListFile, const QString &key, const DN &dn, Key::OwnerTrust trust)
+QString change_trust_file(const QString &trustListFile, const QString &key, const QGpgME::DN &dn, Key::OwnerTrust trust)
 {
     QList<QByteArray> trustListFileContents;
 
