@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    commands/decryptverifyfilescommand.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
@@ -13,9 +11,7 @@
 #include "viewemailfilescommand.h"
 
 #include "command_p.h"
-#include "fileoperationspreferences.h"
 
-#include "crypto/autodecryptverifyfilescontroller.h"
 #include "crypto/decryptverifyfilescontroller.h"
 
 #include <utils/filedialog.h>
@@ -41,7 +37,7 @@ class DecryptVerifyFilesCommand::Private : public Command::Private
     }
 
 public:
-    explicit Private(DecryptVerifyFilesCommand *qq, KeyListController *c, bool forceManualMode = false);
+    explicit Private(DecryptVerifyFilesCommand *qq, KeyListController *c);
     ~Private() override;
 
     QStringList selectFiles() const;
@@ -65,7 +61,6 @@ private:
     void slotControllerError(int, const QString &msg)
     {
         KMessageBox::error(parentWidgetOrView(), msg, i18nc("@title:window", "Decrypt/Verify Failed"));
-        files.clear();
         finishIfEverythingIsDone();
     }
 
@@ -88,17 +83,12 @@ const DecryptVerifyFilesCommand::Private *DecryptVerifyFilesCommand::d_func() co
 #define d d_func()
 #define q q_func()
 
-DecryptVerifyFilesCommand::Private::Private(DecryptVerifyFilesCommand *qq, KeyListController *c, bool forceManualMode)
+DecryptVerifyFilesCommand::Private::Private(DecryptVerifyFilesCommand *qq, KeyListController *c)
     : Command::Private(qq, c)
     , files()
-    , shared_qq(qq, [](DecryptVerifyFilesCommand *) {})
+    , shared_qq(qq, [](DecryptVerifyFilesCommand *) { })
 {
-    FileOperationsPreferences prefs;
-    if (!forceManualMode && prefs.autoDecryptVerify()) {
-        mController = new AutoDecryptVerifyFilesController();
-    } else {
-        mController = new DecryptVerifyFilesController();
-    }
+    mController = new DecryptVerifyFilesController();
 }
 
 DecryptVerifyFilesCommand::Private::~Private()
@@ -119,8 +109,8 @@ DecryptVerifyFilesCommand::DecryptVerifyFilesCommand(QAbstractItemView *v, KeyLi
     d->init();
 }
 
-DecryptVerifyFilesCommand::DecryptVerifyFilesCommand(const QStringList &files, KeyListController *c, bool forceManualMode)
-    : Command(new Private(this, c, forceManualMode))
+DecryptVerifyFilesCommand::DecryptVerifyFilesCommand(const QStringList &files, KeyListController *c)
+    : Command(new Private(this, c))
 {
     d->init();
     d->files = files;
