@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    commands/exportsecretsubkeycommand.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2022 g10 Code GmbH
     SPDX-FileContributor: Ingo Klöcker <dev@ingo-kloecker.de>
