@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    importcertificatefromclipboardcommand.cpp
-
+/*
     This clipboard is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -20,6 +18,7 @@
 #include <gpgme++/global.h>
 
 #include <KLocalizedString>
+#include <KMessageDialog>
 
 #include <QApplication>
 #include <QByteArray>
@@ -29,6 +28,8 @@
 using namespace GpgME;
 using namespace Kleo;
 
+using namespace Qt::Literals::StringLiterals;
+
 class ImportCertificateFromClipboardCommand::Private : public ImportCertificatesCommand::Private
 {
     friend class ::ImportCertificateFromClipboardCommand;
@@ -41,8 +42,6 @@ public:
     explicit Private(ImportCertificateFromClipboardCommand *qq, KeyListController *c);
     ~Private() override;
 
-    bool ensureHaveClipboard();
-
 private:
     QByteArray input;
 };
@@ -93,33 +92,43 @@ ImportCertificateFromClipboardCommand::~ImportCertificateFromClipboardCommand()
 
 void ImportCertificateFromClipboardCommand::doStart()
 {
-    if (!d->ensureHaveClipboard()) {
-        d->canceled();
-        return;
-    }
-
-    d->setWaitForMoreJobs(true);
-    const unsigned int classification = classifyContent(d->input);
-    if (!mayBeAnyCertStoreType(classification)) {
-        d->error(i18n("Clipboard contents do not look like a certificate."), i18n("Certificate Import Failed"));
-    } else {
-        const GpgME::Protocol protocol = findProtocol(classification);
-        if (protocol == GpgME::UnknownProtocol) {
-            d->error(i18n("Could not determine certificate type of clipboard contents."), i18n("Certificate Import Failed"));
+    // Don't remove this dialog, it's required to query the clipboard on wayland
+    auto dialog = new KMessageDialog(KMessageDialog::Information, i18nc("@info", "Importing certificate from clipboard…"), nullptr);
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    auto onClipboardAvailable = [this, dialog]() {
+        dialog->close();
+        d->input = qApp->clipboard()->text().toUtf8();
+        d->setWaitForMoreJobs(true);
+        const unsigned int classification = classifyContent(d->input);
+        if (d->input.isEmpty()) {
+            d->error(i18nc("@info", "The clipboard is empty. Nothing imported."));
+        } else if (!mayBeAnyCertStoreType(classification)) {
+            d->error(i18nc("@info", "Clipboard contents do not look like a certificate. Nothing imported."));
         } else {
-            d->startImport(protocol, d->input, i18n("Clipboard"));
+            const GpgME::Protocol protocol = findProtocol(classification);
+            if (protocol == GpgME::UnknownProtocol) {
+                d->error(i18nc("@info", "Could not determine certificate type of clipboard contents. Nothing imported."));
+            } else {
+                d->startImport(protocol, d->input, i18n("Clipboard"));
+            }
         }
-    }
-    d->setWaitForMoreJobs(false);
-}
+        d->setWaitForMoreJobs(false);
+    };
 
-bool ImportCertificateFromClipboardCommand::Private::ensureHaveClipboard()
-{
-    if (input.isEmpty())
-        if (const QClipboard *cb = qApp->clipboard()) {
-            input = cb->text().toUtf8();
-        }
-    return !input.isEmpty();
+    if (qApp->platformName() != "wayland"_L1) {
+        onClipboardAvailable();
+    } else {
+        dialog->show();
+        // On wayland, the clipboard is not available immediately, but QClipboard::dataChanged is always triggered once we can access it.
+        connect(
+            qApp->clipboard(),
+            &QClipboard::dataChanged,
+            this,
+            [onClipboardAvailable]() {
+                onClipboardAvailable();
+            },
+            Qt::SingleShotConnection);
+    }
 }
 
 #undef d
