@@ -13,7 +13,7 @@
 #include <settings.h>
 
 #include <Libkleo/DNAttributeOrderConfigWidget>
-#include <Libkleo/Dn>
+#include <Libkleo/DnAttributes>
 #include <Libkleo/ExpiryCheckerConfig>
 #include <Libkleo/KeyFilterManager>
 #include <Libkleo/SystemInfo>
@@ -47,10 +47,8 @@ using namespace Kleo;
 using namespace Kleo::Config;
 
 enum {
-    HasNameRole = Qt::UserRole + 0x1234, /*!< Records that the user has assigned a name (to avoid comparing with i18n-strings) */
-    HasFontRole, /*!< Records that the user has chosen  completely different font (as opposed to italic/bold/strikeout) */
+    HasFontRole = Qt::UserRole + 0x1234, /*!< Records that the user has chosen  completely different font (as opposed to italic/bold/strikeout) */
     IconNameRole, /*!< Records the name of the icon (since QIcon won't give it out again, once set) */
-    MayChangeNameRole,
     MayChangeForegroundRole,
     MayChangeBackgroundRole,
     MayChangeFontRole,
@@ -131,8 +129,6 @@ static void apply_config(const KConfigGroup &group, QListWidgetItem *item)
 
     const QString name = group.readEntry("Name");
     item->setText(name.isEmpty() ? i18nc("Key filter without user-assigned name", "<unnamed>") : name);
-    item->setData(HasNameRole, !name.isEmpty());
-    item->setData(MayChangeNameRole, !group.isEntryImmutable("Name"));
     item->setData(ConfigGroupRole, QVariant::fromValue(group));
 
     const QColor fg = group.readEntry("foreground-color", QColor());
@@ -262,7 +258,6 @@ static void save_to_config(const QListWidgetItem *item, KConfigGroup &group)
     if (!item) {
         return;
     }
-    writeOrDelete(group, "Name", item->data(HasNameRole).toBool() ? item->text() : QVariant());
     writeOrDelete(group, "foreground-color", brush2color(item->data(StoredForegroundRole)));
     writeOrDelete(group, "background-color", brush2color(item->data(StoredBackgroundRole)));
     writeOrDelete(group, "icon", item->data(IconNameRole));
@@ -656,7 +651,7 @@ void AppearanceConfigWidget::defaults()
 
     if (d->dnOrderWidget) {
         if (!settings.isImmutable(QStringLiteral("AttributeOrder"))) {
-            d->dnOrderWidget->setAttributeOrder(DN::defaultAttributeOrder());
+            d->dnOrderWidget->setAttributeOrder(DNAttributes::defaultOrder());
         }
     }
 
@@ -691,7 +686,7 @@ void AppearanceConfigWidget::load()
     }
 
     if (d->dnOrderWidget) {
-        d->dnOrderWidget->setAttributeOrder(DN::attributeOrder());
+        d->dnOrderWidget->setAttributeOrder(DNAttributes::order());
         d->dnOrderWidget->setEnabled(!settings.isImmutable(QStringLiteral("AttributeOrder")));
     }
 
@@ -726,7 +721,7 @@ void AppearanceConfigWidget::save()
     settings.setShowExpiryNotifications(d->showExpirationCheckBox->isChecked());
     if (d->dnOrderWidget) {
         settings.setAttributeOrder(d->dnOrderWidget->attributeOrder());
-        DN::setAttributeOrder(settings.attributeOrder());
+        DNAttributes::setOrder(settings.attributeOrder());
     }
 
     {
