@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    decryptverifyemailcontroller.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
@@ -43,7 +41,7 @@ class DecryptVerifyEMailController : public Controller
 {
     Q_OBJECT
 public:
-    explicit DecryptVerifyEMailController(QObject *parent = nullptr);
+    explicit DecryptVerifyEMailController(QObject *parent = nullptr, Task::DataSource dataSource = Task::Files);
     explicit DecryptVerifyEMailController(const std::shared_ptr<const ExecutionContext> &cmd, QObject *parent = nullptr);
 
     ~DecryptVerifyEMailController() override;
