@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/gui/resultitemwidget.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
@@ -13,8 +11,6 @@
 
 #include <crypto/task.h>
 
-#include <utils/pimpl_ptr.h>
-
 #include <memory>
 
 class QString;
@@ -51,7 +47,7 @@ Q_SIGNALS:
 
 private:
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
     Q_PRIVATE_SLOT(d, void slotLinkActivated(QString))
 };
 }
