@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/gui/resultlistwidget.cpp
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2008 Klarälvdalens Datakonsult AB
 
@@ -11,25 +9,17 @@
 
 #include "resultlistwidget.h"
 
-#include "emailoperationspreferences.h"
-
-#include <crypto/decryptverifytask.h>
 #include <crypto/gui/resultitemwidget.h>
 
 #include <utils/gui-helper.h>
-#include <utils/scrollarea.h>
 
 #include <Libkleo/Stl_Util>
 
+#include <KAdjustingScrollArea>
 #include <KLocalizedString>
-#include <KStandardGuiItem>
-#include <QPushButton>
 
-#include <QLabel>
 #include <QVBoxLayout>
 
-#include <KGuiItem>
-
 using namespace Kleo;
 using namespace Kleo::Crypto;
 using namespace Kleo::Crypto::Gui;
@@ -46,15 +36,11 @@ public:
     void allTasksDone();
 
     void addResultWidget(ResultItemWidget *widget);
-    void resizeIfStandalone();
 
     std::vector<std::shared_ptr<TaskCollection>> m_collections;
-    bool m_standaloneMode = false;
     int m_lastErrorItemIndex = 0;
-    ScrollArea *m_scrollArea = nullptr;
-    QPushButton *m_closeButton = nullptr;
+    KAdjustingScrollArea *m_scrollArea = nullptr;
     QVBoxLayout *m_layout = nullptr;
-    QLabel *m_progressLabel = nullptr;
 };
 
 ResultListWidget::Private::Private(ResultListWidget *qq)
@@ -65,26 +51,15 @@ ResultListWidget::Private::Private(ResultListWidget *qq)
     m_layout->setContentsMargins(0, 0, 0, 0);
     m_layout->setSpacing(0);
 
-    m_scrollArea = new ScrollArea;
+    m_scrollArea = new KAdjustingScrollArea;
     m_scrollArea->setFocusPolicy(Qt::NoFocus);
-    auto scrollAreaLayout = qobject_cast<QBoxLayout *>(m_scrollArea->widget()->layout());
-    Q_ASSERT(scrollAreaLayout);
+    auto widget = new QWidget;
+    m_scrollArea->setWidget(widget);
+    auto scrollAreaLayout = new QVBoxLayout(widget);
     scrollAreaLayout->setContentsMargins(0, 0, 0, 0);
     scrollAreaLayout->setSpacing(2);
     scrollAreaLayout->addStretch();
     m_layout->addWidget(m_scrollArea);
-
-    m_progressLabel = new QLabel;
-    m_progressLabel->setWordWrap(true);
-    m_layout->addWidget(m_progressLabel);
-    m_progressLabel->setVisible(false);
-
-    m_closeButton = new QPushButton;
-    KGuiItem::assign(m_closeButton, KStandardGuiItem::close());
-    q->connect(m_closeButton, &QPushButton::clicked, q, &ResultListWidget::close);
-    m_layout->addWidget(m_closeButton);
-    m_closeButton->setVisible(false);
-    m_closeButton->setEnabled(false);
 }
 
 ResultListWidget::ResultListWidget(QWidget *parent, Qt::WindowFlags f)
@@ -93,22 +68,7 @@ ResultListWidget::ResultListWidget(QWidget *parent, Qt::WindowFlags f)
 {
 }
 
-ResultListWidget::~ResultListWidget()
-{
-    if (!d->m_standaloneMode) {
-        return;
-    }
-    EMailOperationsPreferences prefs;
-    prefs.setDecryptVerifyPopupGeometry(geometry());
-    prefs.save();
-}
-
-void ResultListWidget::Private::resizeIfStandalone()
-{
-    if (m_standaloneMode) {
-        q->resize(q->size().expandedTo(q->sizeHint()));
-    }
-}
+ResultListWidget::~ResultListWidget() = default;
 
 void ResultListWidget::Private::addResultWidget(ResultItemWidget *widget)
 {
@@ -132,7 +92,6 @@ void ResultListWidget::Private::addResultWidget(ResultItemWidget *widget)
     }
 
     widget->show();
-    resizeIfStandalone();
 }
 
 void ResultListWidget::Private::allTasksDone()
@@ -140,8 +99,6 @@ void ResultListWidget::Private::allTasksDone()
     if (!q->isComplete()) {
         return;
     }
-    m_progressLabel->setVisible(false);
-    resizeIfStandalone();
     Q_EMIT q->completeChanged();
 }
 
@@ -184,7 +141,6 @@ unsigned int ResultListWidget::numberOfCompletedTasks() const
 
 void ResultListWidget::setTaskCollection(const std::shared_ptr<TaskCollection> &coll)
 {
-    // clear(); ### PENDING(marc) implement
     addTaskCollection(coll);
 }
 
@@ -199,26 +155,11 @@ void ResultListWidget::addTaskCollection(const std::shared_ptr<TaskCollection> &
             SLOT(result(std::shared_ptr<const Kleo::Crypto::Task::Result>)));
     connect(coll.get(), SIGNAL(started(std::shared_ptr<Kleo::Crypto::Task>)), this, SLOT(started(std::shared_ptr<Kleo::Crypto::Task>)));
     connect(coll.get(), SIGNAL(done()), this, SLOT(allTasksDone()));
-    setStandaloneMode(d->m_standaloneMode);
 }
 
 void ResultListWidget::Private::started(const std::shared_ptr<Task> &task)
 {
     Q_ASSERT(task);
-    Q_ASSERT(m_progressLabel);
-    m_progressLabel->setText(i18nc("number, operation description", "Operation %1: %2", q->numberOfCompletedTasks() + 1, task->label()));
-    resizeIfStandalone();
-}
-
-void ResultListWidget::setStandaloneMode(bool standalone)
-{
-    d->m_standaloneMode = standalone;
-    if (totalNumberOfTasks() == 0) {
-        return;
-    }
-    d->m_closeButton->setVisible(standalone);
-    d->m_closeButton->setEnabled(standalone);
-    d->m_progressLabel->setVisible(standalone);
 }
 
 #include "moc_resultlistwidget.cpp"
