@@ -19,6 +19,7 @@
 #include "utils/kleo_assert.h"
 #include <Libkleo/GnuPG>
 
+#include <Libkleo/ApplicationPaletteWatcher>
 #include <Libkleo/Compliance>
 #include <Libkleo/Formatting>
 #include <Libkleo/Stl_Util>
@@ -28,7 +29,6 @@
 
 #include <KMime/Types>
 
-#include <KColorScheme>
 #include <KLocalizedString>
 
 #include <QCheckBox>
@@ -123,6 +123,9 @@ public:
         , presetProtocol(UnknownProtocol)
         , ui(q)
     {
+        connect(&appPaletteWatcher, &ApplicationPaletteWatcher::paletteChanged, q, [this]() {
+            updateComplianceStatus();
+        });
     }
 
 private:
@@ -320,6 +323,7 @@ private:
     }
 
 private:
+    ApplicationPaletteWatcher appPaletteWatcher;
     std::vector<Sender> senders;
     std::vector<Recipient> recipients;
 
