@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/gui/signingcertificateselectiondialog.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2007 Klarälvdalens Datakonsult AB
 
@@ -12,8 +10,6 @@
 
 #include <gpgme++/key.h>
 
-#include <utils/pimpl_ptr.h>
-
 #include <set>
 
 template<typename K, typename U>
