@@ -1,6 +1,4 @@
-/* -*- mode: c++; c-basic-offset:4 -*-
-    crypto/gui/verifychecksumsdialog.h
-
+/*
     This file is part of Kleopatra, the KDE keymanager
     SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB
 
@@ -14,7 +12,7 @@
 
 #ifndef QT_NO_DIRMODEL
 
-#include <utils/pimpl_ptr.h>
+#include <memory>
 
 namespace Kleo
 {
@@ -52,7 +50,7 @@ Q_SIGNALS:
 private:
     Q_PRIVATE_SLOT(d, void slotErrorButtonClicked())
     class Private;
-    kdtools::pimpl_ptr<Private> d;
+    const std::unique_ptr<Private> d;
 };
 }
 }
